/* LIQUIDITY AND THE INTERNATIONAL ALLOCATION OF ECONOMIC ACTIVITY */
/* ANTONIO RODRIGUEZ-LOPEZ */
/* CREATING TRACE BOND YIELD DATA FOR ANALYSIS */
/* NAME OF FINAL FILE IS yields.dta*/
/* DATA COVERS FROM APRIL 2014 TO MARCH 2019
IN STATA MONTHS: 651 TO 710 */


clear all
set more off

*MAC OR PC
*If PC
*local s "\"
*local m "G:\My Drive\"
*If MAC
local s "/"
local m "`s'Data Supplement`s'"


*Directories 

local datadir "`m'data`s'TRACE`s'"
local cmedir "`m'data`s'cme`s'"
local outdir "`m'data`s'yields`s'"


use "`datadir'TRACE_invgrade_cusip.dta", clear

*Remove outliers

drop if close_yld>60
drop if close_yld>20 & day>20600
drop if close_yld>20 & day<20000
drop if close_yld==0
drop if close_yld<1 & cusip_id=="26054LTP8"
drop if close_yld<0.02 & cusip_id=="26054LB28"
drop if close_yld<1 & cusip_id=="26054LE33"
drop if close_yld>10 & cusip_id=="26054LE33"
drop if close_yld<1.13 & cusip_id=="26054LWK5"
drop if close_yld>4 & cusip_id=="29364NAP3"
drop if close_yld<1.2 & cusip_id=="29364NAP3"
drop if close_yld>10 &  company_symbol=="F"
drop if close_yld<0.7 & company_symbol=="NRX"
drop if close_yld>15 & company_symbol=="PSEC"
drop if close_yld<0.26 & company_symbol=="PSEC"
drop if close_yld<1 & cusip_id=="74348YRG8"
drop if cusip_id=="63743FG26"

*Monthly data

collapse (first) company_symbol (mean) close_yld, by(cusip_id month)
ren cusip_id cusip

tempfile trace
save `trace'

*Merge Fidelity list with Moodys ratings and CME acceptability

merge m:1 cusip using "`cmedir'Fidelity_CME.dta" 
drop if _merge==2
drop _merge
drop if moodys_r==.
save "`outdir'yields.dta", replace

*March 2019
keep if month==710
save "`outdir'yields_march19.dta", replace

*Balanced panel
use `trace', clear
merge m:1 cusip using "`cmedir'Fidelity_CME_balanced.dta" 
drop if _merge==2
drop _merge
drop if moodys_r==.
save "`outdir'yields_balanced.dta", replace


