clear all
set more off

*TABLES 4 AND 5: ACCEPTABILITY, ECONOMIC ACTIVITY, AND MARKET-TO-BOOK RATIOS

*MAC OR PC
*If PC
*local s "\"
*local m "G:\My Drive\"
*If MAC
local s "/"
local m "`s'Data Supplement`s'"


*Directories 

local datadir "`m'data`s'firmlevel`s'"
local outdir "`m'out`s'"

*Use file in real 2012 dollars and 47 countries

use "`datadir'firmlevel.dta", clear


tsset gvkey fyear

*Total for industry
foreach v in "sale" "oibdp" "emp" "mkvalt" "xrd"  "seq" {
bys sic fyear: egen ind`v'=total(`v')
}

foreach v in "sale" "oibdp" "emp" "mkvalt" "xrd" "seq" {
gen s`v'=`v'/ind`v'
}

*Operating income as fraction of industry sales (profits measured as fraction of industry sales)
gen soibdp2sale=oibdp/indsale

*Market-to-book ratio
gen m2bratio=mkvalt/seq
egen m2bratio_mean=wtmean(m2bratio), by(sic fyear) weight(seq)
gen sm2bratio=m2bratio/m2bratio_mean
gen lsm2bratio=log(sm2bratio)

collapse (mean) ssale soibdp soibdp2sale semp sxrd smkvalt sseq lsm2bratio stock_acc bond_acc accind seq mkvalt (first) loc (median) loc2 sic sic2, by(gvkey)


*Specification controls, clustering
local controls "i.loc2 i.sic2"
local na_sample "if seq!=. & mkvalt!=."

*TABLE 3: ACCEPTABILITY AND ECONOMIC ACTIVITY


foreach t in "accind"  "stock_acc" "bond_acc" {
eststo m1_`t': reg ssale `t' `controls' , r
eststo m2_`t': reg soibdp2sale `t' `controls' , r
eststo m3_`t': reg semp `t' `controls' , r
eststo m4_`t': reg sxrd `t' `controls' , r
eststo m5_`t': reg sseq `t' `controls' , r
eststo m6_`t': reg smkvalt `t' `controls' `na_sample' , r
eststo m7_`t': reg soibdp `t' `controls' , r
eststo m8_`t': reg sseq `t' `controls' `na_sample' , r
}



*TABLE 4: ACCEPTABILITY AND MARKET-TO-BOOK RATIOS 

eststo n1: reg lsm2bratio accind  `controls' `na_sample', r
eststo n2: reg lsm2bratio accind ssale soibdp2sale `controls' `na_sample', r
eststo n3: reg lsm2bratio stock_acc  `controls' `na_sample', r
eststo n4: reg lsm2bratio stock_acc ssale soibdp2sale `controls' `na_sample', r
eststo n5: reg lsm2bratio bond_acc  `controls' `na_sample' , r
eststo n6: reg lsm2bratio bond_acc ssale soibdp2sale `controls' `na_sample' , r


*Robustness Table 4

foreach t in  "accind"  "stock_acc"  "bond_acc" {
 eststo n7_`t': capture noisily teffects psmatch (lsm2bratio) (`t' ssale soibdp2sale), atet vce(robust)     
}


*OUTPUT	
	foreach f in "accind" "stock_acc" "bond_acc"  {
	esttab m1_`f' m2_`f' m3_`f' m4_`f' m5_`f' m6_`f' m7_`f' m8_`f' using "`outdir'tab4.csv", b(%9.3f) se(%9.3f) star(* .10 ** .05 *** .01) replace
	insheet using "`outdir'tab4.csv", comma clear
	export excel "`outdir'tab4.xlsx", sheetreplace sheet(tab4_`f')
	}
	
	esttab n1 n2 n3 n4 n5 n6 using "`outdir'tab5.csv", b(%9.3f) se(%9.3f) star(* .10 ** .05 *** .01) replace
	insheet using "`outdir'tab5.csv", comma clear
	export excel "`outdir'tab5.xlsx", sheetreplace sheet(tab5)
	

	esttab n7_accind n7_stock_acc n7_bond_acc using "`outdir'tab5.csv", b(%9.3f) se(%9.3f) star(* .10 ** .05 *** .01) replace
	insheet using "`outdir'tab5.csv", comma clear
	export excel "`outdir'tab5.xlsx", sheetreplace sheet(tab5_robust)
	
	


					  
